@@ -26,8 +26,7 @@ impl<'a> Context<'a> {
         let mut attrs: Vec<_> = ast
             .attrs
             .iter()
-            .map(Context::get_rustler_attrs)
-            .flatten()
+            .flat_map(Context::get_rustler_attrs)
             .collect();
 
         //
@@ -127,7 +126,7 @@ impl<'a> Context<'a> {
     pub fn escape_ident_with_index(ident_str: &str, index: usize, infix: &str) -> Ident {
         Ident::new(
             &format!(
-                "RUSTLER_{}_field_{}_{}",
+                "rustler_{}_field_{}_{}",
                 infix,
                 index,
                 Self::remove_raw(ident_str)
@@ -138,7 +137,7 @@ impl<'a> Context<'a> {
 
     pub fn escape_ident(ident_str: &str, infix: &str) -> Ident {
         Ident::new(
-            &format!("RUSTLER_{}_field_{}", infix, Self::remove_raw(ident_str)),
+            &format!("rustler_{}_field_{}", infix, Self::remove_raw(ident_str)),
             Span::call_site(),
         )
     }
