@@ -1,6 +1,7 @@
 use proc_macro2::{Span, TokenStream};
+use quote::{quote, quote_spanned};
 
-use heck::SnakeCase;
+use heck::ToSnakeCase;
 use syn::{self, spanned::Spanned, Fields, Ident, Variant};
 
 use super::context::Context;
